netapp_ontap.resources.vscan_on_demand API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.vscan_on_demand`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Vscan On-Demand scanning is used to check files for viruses on a schedule. For example, it can be used to run scans only in off-peak hours, or to scan very large files that are excluded from an on-access scan. Vscan On-Demand scanning can be used for any path in the SVM namespace.

Vscan On-Demand policy configurations define the scope of a Vscan On-Demand scan. The schedule parameter in the On-Demand policy configuration decides when to execute the task. Schedule can be created using the /api/clusters/schedule endpoint and can be assigned on policy create or policy modify. This API is used to retrieve and manage Vscan On-Demand policy configurations. It is also used to schedule the Vscan On-Demand scan.

## Examples

### Retrieving all fields for all policies of an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(VscanOnDemand.get_collection("{svm.uuid}", fields="*")))

Try it out

    [
        VscanOnDemand(
            {
                "log_path": "/vol0/report_dir",
                "name": "on-demand-policy1",
                "scan_paths": ["/vol1/", "/vol2/cifs/"],
                "schedule": {
                    "_links": {
                        "self": {
                            "href": "/api/cluster/schedules/f6d0843e-f159-11e8-8e22-0050568e0945"
                        }
                    },
                    "name": "schedule",
                    "uuid": "f6d0843e-f159-11e8-8e22-0050568e0945",
                },
                "scope": {
                    "scan_without_extension": False,
                    "max_file_size": 10737418240,
                    "include_extensions": ["vmdk", "mp*"],
                    "exclude_paths": ["/vol1/cold-files/", "/vol1/cifs/names"],
                    "exclude_extensions": ["mp3", "mp4"],
                },
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"
                        }
                    },
                    "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
                },
            }
        ),
        VscanOnDemand(
            {
                "log_path": "/report",
                "name": "on-demand-policy2",
                "scan_paths": ["/vol1/", "/vol2/cifs/"],
                "scope": {
                    "scan_without_extension": True,
                    "max_file_size": 10737418240,
                    "include_extensions": ["mp*"],
                },
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"
                        }
                    },
                    "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
                },
            }
        ),
    ]

### Retrieving a specific On-Demand policy associated with a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanOnDemand(
            "86fbc414-f140-11e8-8e22-0050568e0945", name="on-demand-task"
        )
        resource.get()
        print(resource)

Try it out

    VscanOnDemand(
        {
            "log_path": "/report",
            "name": "on-demand-policy",
            "scan_paths": ["/vol1/cifs"],
            "scope": {
                "scan_without_extension": True,
                "max_file_size": 10737418240,
                "include_extensions": ["vmdk", "mp*"],
            },
            "svm": {
                "name": "vs1",
                "_links": {
                    "self": {"href": "/api/svm/svms/86fbc414-f140-11e8-8e22-0050568e0945"}
                },
                "uuid": "86fbc414-f140-11e8-8e22-0050568e0945",
            },
        }
    )

### Creating a Vscan On-Demand policy

The Vscan On-Demand policy POST endpoint creates an On-Demand policy for the specified SVM. Specify the schedule parameter to schedule an On-Demand scan.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanOnDemand("86fbc414-f140-11e8-8e22-0050568e0945")
        resource.log_path = "/vol0/report_dir"
        resource.name = "on-demand-policy"
        resource.scan_paths = ["/vol1/", "/vol2/cifs/"]
        resource.schedule = {
            "name": "weekly",
            "uuid": "1cd8a442-86d1-11e0-ae1c-123478563412",
        }
        resource.scope = {
            "exclude_extensions": ["mp3"],
            "exclude_paths": ["/vol/cold-files/"],
            "include_extensions": ["vmdk", "mp*"],
            "max_file_size": 1073741824,
            "scan_without_extension": True,
        }
        resource.post(hydrate=True)
        print(resource)

Try it out

    VscanOnDemand(
        {
            "log_path": "/vol0/report_dir",
            "name": "on-demand-policy",
            "scan_paths": ["/vol1/", "/vol2/cifs/"],
            "schedule": {"name": "weekly"},
            "scope": {
                "scan_without_extension": True,
                "max_file_size": 1073741824,
                "include_extensions": ["vmdk", "mp*"],
                "exclude_paths": ["/vol/cold-files/"],
                "exclude_extensions": ["mp3"],
            },
            "svm": {"name": "vs1"},
        }
    )

### Creating a Vscan On-Demand policy where a number of optional fields are not specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanOnDemand("86fbc414-f140-11e8-8e22-0050568e0945")
        resource.log_path = "/report"
        resource.name = "on-demand-policy"
        resource.scan_paths = ["/vol1/cifs/"]
        resource.scope = {"include_extensions": ["mp*"], "scan_without_extension": True}
        resource.post(hydrate=True)
        print(resource)

Try it out

    VscanOnDemand(
        {
            "log_path": "/report",
            "name": "on-demand-policy",
            "scan_paths": ["vol1/cifs/"],
            "scope": {
                "scan_without_extension": True,
                "max_file_size": 10737418240,
                "include_extensions": ["vmdk", "mp*"],
            },
            "svm": {"name": "vs1"},
        }
    )

### Updating a Vscan On-Demand policy

The policy being modified is identified by the UUID of the SVM and the policy name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanOnDemand(
            "86fbc414-f140-11e8-8e22-0050568e0945", name="on-demand-policy"
        )
        resource.schedule = {"name": "weekly"}
        resource.scope = {
            "exclude_extensions": ["mp3"],
            "exclude_paths": ["/vol/"],
            "include_extensions": ["vmdk", "mp3"],
            "scan_without_extension": True,
        }
        resource.patch()

### Deleting a Vscan On-Demand policy

The policy to be deleted is identified by the UUID of the SVM and the policy name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanOnDemand

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanOnDemand(
            "86fbc414-f140-11e8-8e22-0050568e0945", name="on-demand-policy"
        )
        resource.delete()

## Classes

`class VscanOnDemand (*args, **kwargs)`

  Use On-Demand scanning to check files for viruses on a schedule. An On-Demand policy defines the scope of an On-Demand scan.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all VscanOnDemand resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('VscanOnDemand')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the Vscan On-Demand configuration.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task delete`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent VscanOnDemand resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the Vscan On-Demand policy.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the Vscan On-Demand policy.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('VscanOnDemand')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the Vscan On-Demand policy configuration of an SVM. Use schedule name or schedule UUID to schedule an On-Demand scan.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task modify`
    - `vserver vscan on-demand-task schedule`
    - `vserver vscan on-demand-task unschedule`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('VscanOnDemand')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[VscanOnDemand], NetAppResponse]`

    Creates a Vscan On-Demand policy. Created only on a data SVM. Important notes: * Only one policy can be scheduled at a time on an SVM. Use schedule name or schedule uuid to schedule an On-Demand policy. * Scanning must be enabled on the SVM before the policy is scheduled to run. * The exclude_extensions setting overrides the include_extensions setting. Set scan_without_extension to true to scan files without extensions.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the Vscan On-Demand policy.
    - `name` - Name of the Vscan On-Demand policy. Maximum length is 256 characters.
    - `log_path` - Path from the Vserver root where the On-Demand policy report is created.
    - `scan_paths` - List of paths that need to be scanned.

    ### Recommended optional properties

    - `schedule` - Scan schedule. It is recommended to set the schedule property, as it dictates when to scan for viruses.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `include_extensions` - * * `max_file_size` - 10737418240 * `scan_without_extension` - true

    ### Related ONTAP commands

    - `vserver vscan on-demand-task create`
    - `vserver vscan on-demand-task schedule`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the Vscan On-Demand configuration.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task delete`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the Vscan On-Demand configuration of an SVM.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the Vscan On-Demand policy configuration of an SVM. Use schedule name or schedule UUID to schedule an On-Demand scan.

    ### Related ONTAP commands

    - `vserver vscan on-demand-task modify`
    - `vserver vscan on-demand-task schedule`
    - `vserver vscan on-demand-task unschedule`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a Vscan On-Demand policy. Created only on a data SVM. Important notes: * Only one policy can be scheduled at a time on an SVM. Use schedule name or schedule uuid to schedule an On-Demand policy. * Scanning must be enabled on the SVM before the policy is scheduled to run. * The exclude_extensions setting overrides the include_extensions setting. Set scan_without_extension to true to scan files without extensions.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the Vscan On-Demand policy.
    - `name` - Name of the Vscan On-Demand policy. Maximum length is 256 characters.
    - `log_path` - Path from the Vserver root where the On-Demand policy report is created.
    - `scan_paths` - List of paths that need to be scanned.

    ### Recommended optional properties

    - `schedule` - Scan schedule. It is recommended to set the schedule property, as it dictates when to scan for viruses.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `include_extensions` - * * `max_file_size` - 10737418240 * `scan_without_extension` - true

    ### Related ONTAP commands

    - `vserver vscan on-demand-task create`
    - `vserver vscan on-demand-task schedule`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/on-demand-policies`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class VscanOnDemandSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VscanOnDemand object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `log_path: str GET POST PATCH`

    The path from the Vserver root where the task report is created.

    Example: /vol0/report_dir

  `name: str GET POST`

    On-Demand task name

    Example: task-1

  `scan_paths: List[str] GET POST PATCH`

    List of paths that need to be scanned.

    Example: ["/vol1/","/vol2/cifs/"]

  `schedule: Schedule GET POST PATCH`

    The schedule field of the vscan_on_demand.

  `scope: VscanOnDemandScope GET POST PATCH`

    The scope field of the vscan_on_demand.

  `svm: Svm GET`

    The svm field of the vscan_on_demand.